Struct StoreSimpleSled

pub struct StoreSimpleSled<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT>
where N: NamespaceId + EncodableKnownSize + Decodable, S: SubspaceId, PD: PayloadDigest, AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
{ /* private fields */ }
A simple, sled-powered Willow data store implementing the willow_data_model::Store trait.

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> StoreSimpleSled<MCL, MCC, MPL, N, S, PD, AT>

pub fn new(namespace: &N, db: Db) -> Result<Self, NewStoreSimpleSledError>

Returns an empty StoreSimpleSled, or an error if the database is already found to have data in it.

pub fn new_with_event_queue_capacity( namespace: &N, db: Db, capacity: usize, ) -> Result<Self, NewStoreSimpleSledError>

Returns an empty StoreSimpleSled with a given event queue capacity, or an error if the database is already found to have data in it.

pub fn from_existing(db: Db) -> Result<Self, ExistingStoreSimpleSledError>

Returns a StoreSimpleSled from a sled::Db already containing Willow data, or an error if the data is found to be malformed.

pub fn from_existing_with_event_queue_capacity( db: Db, capacity: usize, ) -> Result<Self, ExistingStoreSimpleSledError>

Returns a StoreSimpleSled from a sled::Db already containing Willow data with a given event queue capacity, or an error if the data is found to be malformed.

pub fn clear(&self) -> Result<(), StoreSimpleSledError>

Clear all data from the internal sled::Db